@@ -2,6 +2,7 @@
 import asyncio
 import io
 import os
+import signal
 import subprocess
 import sys
 import time
@@ -60,6 +61,7 @@ class FakePopen:
         wait: Optional[float] = None,
         callback: Optional[Callable] = None,
         callback_kwargs: Optional[Dict[str, AnyType]] = None,
+        signal_callback: Optional[Callable] = None,
         stdin_callable: Optional[Callable] = None,
         **_: Dict[str, AnyType]
     ) -> None:
@@ -71,7 +73,9 @@ class FakePopen:
         self.__thread: Optional[Thread] = None
         self.__callback: Optional[Optional[Callable]] = callback
         self.__callback_kwargs: Optional[Dict[str, AnyType]] = callback_kwargs
+        self.__signal_callback: Optional[Callable] = signal_callback
         self.__stdin_callable: Optional[Optional[Callable]] = stdin_callable
+        self._signals: List[int] = []
 
     def __enter__(self) -> "FakePopen":
         return self
@@ -126,6 +130,20 @@ class FakePopen:
             raise PluginInternalError
         return self.returncode
 
+    def send_signal(self, sig: int) -> None:
+        self._signals.append(sig)
+        if self.__signal_callback:
+            self.__signal_callback(self, sig)
+
+    def terminate(self) -> None:
+        self.send_signal(signal.SIGTERM)
+
+    def kill(self) -> None:
+        if sys.platform == "win32":
+            self.terminate()
+        else:
+            self.send_signal(signal.SIGKILL)
+
     def configure(self, **kwargs: Optional[Dict]) -> None:
         """Setup the FakePopen instance based on a real Popen arguments."""
         self.__universal_newlines = kwargs.get("universal_newlines", None)
@@ -233,6 +251,10 @@ class FakePopen:
         if self.stderr:
             self.stderr.seek(0)
 
+    def received_signals(self) -> Tuple[int, ...]:
+        """Get a tuple of signals received by the process."""
+        return tuple(self._signals)
+
 
 class AsyncFakePopen(FakePopen):
     """Class to handle async processes"""
@@ -455,6 +477,7 @@ class FakeProcess:
         wait: Optional[float] = None,
         callback: Optional[Callable] = None,
         callback_kwargs: Optional[Dict[str, AnyType]] = None,
+        signal_callback: Optional[Callable] = None,
         occurrences: int = 1,
         stdin_callable: Optional[Callable] = None,
     ) -> None:
@@ -489,6 +512,7 @@ class FakeProcess:
                     "wait": wait,
                     "callback": callback,
                     "callback_kwargs": callback_kwargs,
+                    "signal_callback": signal_callback,
                     "stdin_callable": stdin_callable,
                 }
             ]
